summaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authorFlorian Weimer <fw@deneb.enyo.de>2006-12-10 18:36:34 +0000
committerFlorian Weimer <fw@deneb.enyo.de>2006-12-10 18:36:34 +0000
commit59b2bebacd708f274af324d5a101969419cd69cc (patch)
treebff8f1e93af36a31488616a61e9996023e90576a /lib
parent1a1e9d7682ae97c230978794a1557621c223af1b (diff)
Various changes to switch from FAKE- to TEMP- prefixes
(Yeah, less than stellar engineering that this isn't concentrated in a single place.) git-svn-id: svn+ssh://svn.debian.org/svn/secure-testing@5103 e39458fd-73e7-0310-bf30-c45bca0a0e42
Diffstat (limited to 'lib')
-rw-r--r--lib/python/bugs.py2
-rw-r--r--lib/python/security_db.py16
2 files changed, 9 insertions, 9 deletions
diff --git a/lib/python/bugs.py b/lib/python/bugs.py
index 877dedf59a..1db45c6770 100644
--- a/lib/python/bugs.py
+++ b/lib/python/bugs.py
@@ -761,7 +761,7 @@ class FileBase(debian_support.PackageFile):
break
if first_bug:
break
- record_name = 'FAKE-%07d-%06d' % (first_bug, first_lineno)
+ record_name = 'TEMP-%07d-%06d' % (first_bug, first_lineno)
yield self.finishBug(Bug(self.file.name, first_lineno, date,
record_name, description,
comments, notes=pkg_notes, xref=xref))
diff --git a/lib/python/security_db.py b/lib/python/security_db.py
index 532a65f487..6433acd664 100644
--- a/lib/python/security_db.py
+++ b/lib/python/security_db.py
@@ -1299,7 +1299,7 @@ class DB:
else:
release = 'sid'
- c.execute("""DELETE FROM vulnlist WHERE name LIKE 'FAKE-0000000-%'""")
+ c.execute("""DELETE FROM vulnlist WHERE name LIKE 'TEMP-0000000-%'""")
urgency_to_flag = {'low' : 'L', 'medium' : 'M', 'high' : 'H',
'unknown' : ' '}
@@ -1326,7 +1326,7 @@ class DB:
# makes the name unique) is completely useless for the
# client.
- if name[0:5] == "FAKE-":
+ if name[0:5] == 'TEMP-':
name = '-'.join(name.split('-')[0:2])
# Determine if a fix is available for the specific
@@ -1405,8 +1405,8 @@ class DB:
(SELECT range_remote FROM nvd_data
WHERE cve_name = p.bug_name)
FROM package_notes AS p, bugs AS b
WHERE (p.bug_name LIKE 'CVE-%' OR p.bug_name LIKE 'FAKE-%')
AND p.bug_name NOT LIKE 'FAKE-0000000-%'
AND p.urgency <> 'unimportant'
AND COALESCE(p.fixed_version, '') <> '0'
AND p.package_kind IN ('source', 'binary', 'unknown')
@@ -1423,7 +1423,7 @@ class DB:
# makes the name unique) is completely useless for the
# client.
- if bug[0:5] == "FAKE-":
+ if bug[0:5] == 'TEMP-':
name = '-'.join(bug.split('-')[0:2])
else:
name = bug
@@ -1444,8 +1444,8 @@ class DB:
for (bug, package) in list(c.execute(
"""SELECT DISTINCT bug_name, package
FROM package_notes
WHERE (bug_name LIKE 'CVE-%' OR bug_name LIKE 'FAKE-%')
AND bug_name NOT LIKE 'FAKE-0000000-%'
AND package_kind IN ('source', 'binary', 'unknown')
GROUP BY package, bug_name
ORDER BY package, bug_name""")):
@@ -1906,7 +1906,7 @@ class DB:
return list(cursor.execute(
"""SELECT name, description FROM bugs
- WHERE name > 'FAKE-' AND name LIKE 'FAKE-%'
+ WHERE name > 'TEMP-' AND name LIKE 'TEMP-%'
ORDER BY name"""))
def getITPs(self, cursor):
@@ -1405,8 +1405,8 @@ class DB:
WHERE cve_name = p.bug_name)
FROM package_notes AS p, bugs AS b
- WHERE (p.bug_name LIKE 'CVE-%' OR p.bug_name LIKE 'FAKE-%')
- AND p.bug_name NOT LIKE 'FAKE-0000000-%'
+ WHERE (p.bug_name LIKE 'CVE-%' OR p.bug_name LIKE 'TEMP-%')
+ AND p.bug_name NOT LIKE 'TEMP-0000000-%'
AND p.urgency <> 'unimportant'
AND COALESCE(p.fixed_version, '') <> '0'
@@ -1444,8 +1444,8 @@ class DB:
"""SELECT DISTINCT bug_name, package
FROM package_notes
- WHERE (bug_name LIKE 'CVE-%' OR bug_name LIKE 'FAKE-%')
- AND bug_name NOT LIKE 'FAKE-0000000-%'
+ WHERE (bug_name LIKE 'CVE-%' OR bug_name LIKE 'TEMP-%')
+ AND bug_name NOT LIKE 'TEMP-0000000-%'
AND package_kind IN ('source', 'binary', 'unknown')
GROUP BY package, bug_name

© 2014-2024 Faster IT GmbH | imprint | privacy policy